@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import time, gc
+import time, gc, threading
 from .. import es, dataDispose, imatrix
 from numpy import *
 
@@ -25,6 +25,44 @@ def test():
 	print(imatrix.inOne(mat(l)))
 	'''
 
+class GetHitsThread(threading.Thread):
+
+	def __init__(self, first, last):
+		threading.Thread.__init__(self)
+		self.first = first
+		self.last = last
+		self.hits = []
+
+	def run(self):
+		self.hits = es.scrollSearch('statistics_works_hot_fixed_backups', 'recommendviewrecordsearch', {"query":{"bool":{"must":[{"range":{"time":{"gte": 1545448032000, "lte":1550804832000}}},{"range":{"uid":{"gte":self.first,"lte":self.last}}}]}},"size":10000})
+
+def getHits(uids):
+	GetHitsThreads = []
+
+	firstIndex = 0
+	while firstIndex < len(uids):
+		if len(threading.enumerate()) > 6:
+			#time.sleep(1)
+			pass
+		else:
+			lastIndex = min(firstIndex + 9999, len(uids) - 1)
+			print(firstIndex, lastIndex)
+			t = GetHitsThread(uids[firstIndex], uids[lastIndex])
+			GetHitsThreads.append(t)
+			t.setDaemon(True)
+			t.start()
+			firstIndex = lastIndex + 1
+
+	while len(threading.enumerate()) != 1:
+		#time.sleep(1)
+		pass
+
+	hits = []
+	for t in GetHitsThreads:
+		hits.extend(t.hits)
+
+	return hits
+
 def recordEsToRedisBatch():
 	currentUid = readEndUid()
 	index = 0
@@ -35,24 +73,30 @@ def recordEsToRedisBatch():
 		if len(nextUids) == 0:
 			break
 		hitIntsDict = {}
-		hits = es.scrollSearch('statistics_works_hot_fixed_backups', 'recommendviewrecordsearch', {"query":{"bool":{"must":[{"range":{"time":{"lte":1550567166000}}},{"range":{"uid":{"gte":nextUids[0],"lte":nextUids[-1]}}}]}},"size":10000})
+		#hits = es.scrollSearch('statistics_works_hot_fixed_backups', 'recommendviewrecordsearch', {"query":{"bool":{"must":[{"range":{"time":{"lte":1550567166000}}},{"range":{"uid":{"gte":nextUids[0],"lte":nextUids[-1]}}}]}},"size":10000})
+		#hits = es.scrollSearch('statistics_works_hot_fixed_backups', 'recommendviewrecordsearch', {"query":{"bool":{"must":[{"range":{"time":{"lte":1550567166000}}},{"terms":{"uid":nextUids}}]}},"size":10000})
+		hits = getHits(nextUids)
+
 		print(time.time() - start)
 		for hit in hits:
 			uid = hit['_source']['uid']
-			vid = str(es.getIntByVid(hit['_parent']))
+			vid = es.getIntByVid(hit['_parent'])
+			if vid == 0:
+				continue
+			vid = str(vid)
 			if hitIntsDict.has_key(uid):
 				hitIntsDict[uid].append(vid)
 			else:
 				hitIntsDict[uid] = [vid]
 		for nextUid in nextUids:
-			index += 1
+			#index += 1
 			if not hitIntsDict.has_key(nextUid):
 				continue
 			hitInts = hitIntsDict[nextUid]
-			print(index, nextUid, len(hitInts))
+			#print(index, nextUid, len(hitInts), hitInts)
 			es.writeIntsByUid(nextUid, hitInts)
 			writeEndUid(nextUid)
-			writeUids(nextUid)
+			writeUids(nextUid, len(hitInts))
 			currentUid = nextUid
 		print(time.time() - start)
 		gc.collect()
@@ -95,9 +139,9 @@ def writeEndUid(uid):
 	with open('endUid.ini', 'w') as f:
 		f.write(str(uid))
 
-def writeUids(uid):
+def writeUids(uid, count):
 	with open('uids', 'a') as f:
-		f.write('{"uid":' + str(uid) + ',"r1size":8,"r2size":2}\n')
+		f.write('{"uid":' + str(uid) + ',"count":' + str(count) + ',"r1size":8,"r2size":2}\n')
 
 def hotGrow():
 	for vid in ["8133878fd33659cd57fac322e6e08e53", "b9ee6b64790042a3de02b430edd359c1", "2cdef127c294230a2d86438a79c4db3f", "54423e3437395068981e503ec646e682", "c9c2ad4ab7c4c3680e7d0ef5b0c909c9", "ab68fbda808b6c5ab1c84e43c3a1aedc", "a39f8db3de774426e5500b468adcd3b0"]:
